==> v5.1.1.tar.gz: barker/bookie/src/app/discount-report/discount-report.service.ts <==
import { HttpClient, HttpParams } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs/internal/Observable';
import { catchError } from 'rxjs/operators';

import { ErrorLoggerService } from '../core/error-logger.service';

import { DiscountReport } from './discount-report';

const url = '/api/discount-report';
const serviceName = 'DiscountReportService';

@Injectable({
  providedIn: 'root',
})
export class DiscountReportService {
  constructor(private http: HttpClient, private log: ErrorLoggerService) {}

  get(startDate: string | null, finishDate: string | null): Observable<DiscountReport> {
    const options = { params: new HttpParams() };
    if (startDate !== null) {
      options.params = options.params.set('s', startDate);
    }
    if (finishDate !== null) {
      options.params = options.params.set('f', finishDate);
    }
    return <Observable<DiscountReport>>(
      this.http
        .get<DiscountReport>(url, options)
        .pipe(catchError(this.log.handleError(serviceName, 'get')))
    );
  }

  print(startDate: string | null, finishDate: string | null): Observable<boolean> {
    const printUrl = `${url}/print`;
    const options = { params: new HttpParams() };
    if (startDate !== null) {
      options.params = options.params.set('s', startDate);
    }
    if (finishDate !== null) {
      options.params = options.params.set('f', finishDate);
    }
    return <Observable<boolean>>(
      this.http
        .get<boolean>(printUrl, options)
        .pipe(catchError(this.log.handleError(serviceName, 'print')))
    );
  }
}

==> v11.6.2.tar.gz: barker/bookie/src/app/discount-report/discount-report.service.ts <==
import { HttpClient, HttpParams } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { catchError } from 'rxjs/operators';

import { ErrorLoggerService } from '../core/error-logger.service';

import { DiscountReport } from './discount-report';

const url = '/api/discount-report';
const serviceName = 'DiscountReportService';

@Injectable({
  providedIn: 'root',
})
export class DiscountReportService {
  constructor(
    private http: HttpClient,
    private log: ErrorLoggerService,
  ) {}

  get(startDate: string | null, finishDate: string | null): Observable<DiscountReport> {
    const options = { params: new HttpParams() };
    if (startDate !== null) {
      options.params = options.params.set('s', startDate);
    }
    if (finishDate !== null) {
      options.params = options.params.set('f', finishDate);
    }
    return this.http
      .get<DiscountReport>(url, options)
      .pipe(catchError(this.log.handleError(serviceName, 'get'))) as Observable<DiscountReport>;
  }

  print(startDate: string | null, finishDate: string | null): Observable<boolean> {
    const printUrl = `${url}/print`;
    const options = { params: new HttpParams() };
    if (startDate !== null) {
      options.params = options.params.set('s', startDate);
    }
    if (finishDate !== null) {
      options.params = options.params.set('f', finishDate);
    }
    return this.http
      .get<boolean>(printUrl, options)
      .pipe(catchError(this.log.handleError(serviceName, 'print'))) as Observable<boolean>;
  }
}
